@@ -194,12 +194,19 @@ bool Entry::setField(Tellico::Data::FieldPtr field_, const QString& value_) {
 
 bool Entry::setField(const QString& name_, const QString& value_) {
   if(name_.isEmpty()) {
-    myWarning() << "empty field name for value: " << value_;
+    myWarning() << "empty field name for value:" << value_;
     return false;
   }
 
-  if(m_coll->fields().isEmpty() || !m_coll->hasField(name_)) {
-    myDebug() << "unknown collection entry field -" << name_;
+  if(m_coll->fields().isEmpty()) {
+    myDebug() << "collection has no fields, can't add -" << name_;
+    return false;
+  }
+
+  if(!m_coll->hasField(name_)) {
+    myDebug() << "unknown collection entry field -" << name_
+              << "in collection" << m_coll->title();
+    myDebug() <<  "not adding" << value_;
     return false;
   }
 
@@ -255,18 +262,15 @@ bool Entry::addToGroup(EntryGroup* group_) {
 
   m_groups.push_back(group_);
   group_->append(EntryPtr(this));
-//  m_coll->groupModified(group_);
   return true;
 }
 
 bool Entry::removeFromGroup(EntryGroup* group_) {
   // if the removal isn't successful, just return
-  bool success = m_groups.removeAll(group_);
-  success = success && group_->removeAll(EntryPtr(this));
+  bool success = m_groups.removeOne(group_);
+  success = group_->removeOne(EntryPtr(this)) && success;
 //  myDebug() << "removing from group - " << group_->fieldName() << "--" << group_->groupName();
-  if(success) {
-//    m_coll->groupModified(group_);
-  } else {
+  if(!success) {
     myDebug() << "failed!";
   }
   return success;
@@ -299,7 +303,8 @@ QStringList Entry::groupNamesByFieldName(const QString& fieldName_) const {
       }
     }
   } else if(f->hasFlag(Field::AllowMultiple)) {
-    groups.add(FieldFormat::splitValue(formattedField(f)));
+    // use a string split instead of regexp split. since we've already enforced the space after the semi-comma
+    groups.add(FieldFormat::splitValue(formattedField(f), FieldFormat::StringSplit));
   } else {
     groups.add(formattedField(f));
   }
