@@ -80,6 +80,7 @@ public:
    * Returns the name of the data source, as defined by the user.
    */
   virtual QString source() const = 0;
+  virtual QString attribution() const { return QString(); }
   /**
    * Returns the collection type of the most recent search
    */
@@ -90,6 +91,7 @@ public:
   bool updateOverwrite() const;
   const FetchRequest& request() const;
   QStringList optionalFields() const { return m_fields; }
+  QString uuid() const { return m_uuid; }
   /**
    * Starts a search, using a key and value. Calls search()
    */
@@ -157,6 +159,7 @@ private:
   MessageHandler* m_messager;
   QString m_configGroup;
   QStringList m_fields;
+  QString m_uuid;
 };
 
   } // end namespace
