@@ -201,7 +201,7 @@ bool CollectionHandler::end(const QString&, const QString&, const QString&) {
         KUrl u(value);
         // the image file name is a valid URL, but I want it to be a local URL or non empty remote one
         if(u.isValid() && (u.isLocalFile() || !u.host().isEmpty())) {
-          QString result = ImageFactory::addImage(u, imageWarnings >= maxImageWarnings /* quiet */);
+          QString result = ImageFactory::addImage(u, !d->showImageLoadErrors || imageWarnings >= maxImageWarnings /* quiet */);
           if(result.isEmpty()) {
             // clear value for the field in this case
             value.clear();
@@ -286,7 +286,7 @@ StateHandler* FieldHandler::nextHandlerImpl(const QString&, const QString& local
 }
 
 bool FieldHandler::start(const QString&, const QString&, const QString&, const QXmlAttributes& atts_) {
-  // special case: if the i18n attribute equals true, then translate the title, description, and category
+  // special case: if the i18n attribute equals true, then translate the title, description, category, and allowed
   const bool isI18n = attValue(atts_, "i18n") == QLatin1String("true");
 
   QString name = attValue(atts_, "name", "unknown");
@@ -486,9 +486,10 @@ bool EntryHandler::start(const QString&, const QString&, const QString&, const Q
 
     myWarning() << "entries should come after fields are defined, attempting to recover";
   }
-  int id = attValue(atts_, "id").toInt();
+  bool ok;
+  const int id = attValue(atts_, "id").toInt(&ok);
   Data::EntryPtr entry;
-  if(id > 0) {
+  if(ok && id > -1) {
     entry = new Data::Entry(d->coll, id);
   } else {
     entry = new Data::Entry(d->coll);
@@ -575,6 +576,10 @@ bool FieldValueHandler::end(const QString&, const QString& localName_, const QSt
     }
 #endif
     fieldValue = d->textBuffer;
+    // the text buffer has the column delimiter at the end, remove it
+    if(f->type() == Data::Field::Table) {
+      fieldValue.chop(FieldFormat::columnDelimiterString().length());
+    }
     d->textBuffer.clear();
   }
   // this is not an else branch, the data may be in the textBuffer
@@ -654,10 +659,7 @@ bool TableColumnHandler::end(const QString&, const QString&, const QString&) {
     }
   }
 
-  if(!d->textBuffer.isEmpty()) {
-    d->textBuffer += FieldFormat::columnDelimiterString();
-  }
-  d->textBuffer += d->text;
+  d->textBuffer += d->text + FieldFormat::columnDelimiterString();
   return true;
 }
 
